#!/usr/bin/perl
#
# (C) 2001-2003
#	Pozsar Balazs	<pozsy@uhulinux.hu>
#
# This file is originally part of the UHU-Linux distribution.
# Distributable under GPL v2.
#

# ----- Pragmatic modules -----------------------------------------------------
use strict;
use warnings;

# -----------------------------------------------------------------------------
package UHU::module;

use UHU::gtk2;
use UHU::common;

use Locale::gettext;
use Encode;
# ----- Exporter --------------------------------------------------------------
require Exporter;
our @ISA    = qw(Exporter);
our @EXPORT = qw(
droot lroot ddir ldir

start_module quit_module
showmsg hidemsg

load_module_ui
);

my $module;
my $domain;

sub import($$;$) {
	(undef, $module, $domain) = @_;

	$module = ($module or '/');
	$domain = ($domain or '/');

	debug "UHU::module imported."
	. ($module ? " module=[$module]" : '')
	. ($domain ? " domain=[$domain]" : '');

	my $textdomain = ($domain eq '/') ? $module : $domain;
	textdomain $textdomain;
	bind_textdomain_codeset $textdomain, 'utf8';
	UHU::module->export_to_level(1);
}
# ----- I18N ------------------------------------------------------------------
sub _ {
	my ($string, @rest) = @_;

	my $tr = gettext($string);
	Encode::_utf8_on($tr);
	sprintf($tr, @rest);
}

# ----- Subroutines -----------------------------------------------------------
my $main_window;

sub droot() {
	$ENV{MODULE_ROOT} . '/' . $ENV{MODULE_DDIR_ROOT} . '/' . $domain . '/';
}

sub lroot() {
	$ENV{MODULE_ROOT} . '/' . $ENV{MODULE_LDIR_ROOT} . '/' . $domain . '/';
}

sub ddir() {
	if ($ENV{UHU_SRC}) {
		$ENV{MODULE_ROOT} . '/ui/'. ($domain ne '/' ? 'modules' : '')  .'/';
	} else {
		droot . '/' . $module . '/';
	}
}

sub ldir() {
	if ($ENV{UHU_SRC}) {
		if ($module eq 'uhu-control-center') {
			$ENV{MODULE_ROOT} . '/src/modules/';
		} else {
			$ENV{MODULE_ROOT} . '/src/'. ($domain ne '/' ? 'modules' : '') . '/';
		}
	} else {
		if ($module eq 'uhu-control-center') {
			$ENV{MODULE_ROOT} . '/usr/sbin';
		} else {
			lroot . '/' . $module . '/';
		}
	}
}

my $notebook;
my $label;

sub showmsg($) {
	my ($msg) = @_;

	debug "New message:";
	debug $msg;
	$label->set_text($msg);
	$notebook->set_current_page(0);
	set_cursor $notebook, 'watch';
}

sub hidemsg() {
	debug "Hiding message tab, showing main tab.";
	$notebook->set_current_page(1);
	set_cursor $notebook;
}

sub start_module() {
	debug "start_module [$domain][$module]";
	kill 12, $ENV{JUHHU_PID} if $ENV{JUHHU_PID};
	hidemsg;
	main Gtk2;
}

sub quit_module() {
	debug "quit_module [$domain][$module]";
	if ($ENV{JUHHU_PID}) {
		kill 10, $ENV{JUHHU_PID};
	} else {
		showmsg _("Please wait...");
		exit 0;
	}
}

sub load_module_ui(;$$) {
	my ($msg, $screensize) = @_;

	my $ui = ddir . '/' . $module . '.glade2';

	my $parent;
	if ($ENV{JUHHU_XID}) {
		$parent = plug $ENV{JUHHU_XID};
	} else {
		$parent = new Gtk2::Window 'toplevel';
		$parent->set_resizable(0);
		if ($screensize) {
			$parent->set_default_size(($screensize eq 'fullscreen') ? Xres : split /x/, $screensize);
		}
	}

	$parent->signal_connect('remove', \&quit_module);
	$parent->show;

	$notebook = new Gtk2::Notebook;
	$notebook->set_show_tabs(0);
	$notebook->set_show_border(0);
	$notebook->show;
	$parent->add($notebook);

	$label = new Gtk2::Label;
	$label->show;
	$notebook->append_page($label, new Gtk2::Label);

	showmsg($msg or _("Please wait..."));

	my $vbox = new Gtk2::VBox;
	$vbox->show;
	$notebook->append_page($vbox, new Gtk2::Label);

	my $g = load_ui_into_container($ui, 'main', $vbox);
	w($g, 'window')->hide;
	w($g, 'window')->destroy;

	set_cursor w($g, 'main'), 'watch';

	gtk_iterate;

	$g;
}

# ----- Initialization --------------------------------------------------------
$ENV{MODULE_ROOT} ||= '/';
$ENV{MODULE_DDIR_ROOT} ||= '/usr/share';
$ENV{MODULE_LDIR_ROOT} ||= '/usr/lib';

# ----- Beatiful perl :) ------------------------------------------------------
"Indul a gorog a ludnI";
